<div align="center">
    <h1>py-wants-to-party</h1>
    <h3>An API wrapper for the <a href="https://wants-to.party">wants-to.party</a> API.</h3>
    <h2> Currently under development.</h2>
    
</div>


## Getting started
Todo.

## Examples
Todo.

## License
This is licensed under MIT. Read the license [here](LICENSE.txt).